/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.el;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.codehaus.jackson.JsonGenerationException;
import org.codehaus.jackson.map.JsonMappingException;
import org.codehaus.jackson.map.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import se.vgregion.ifeed.formbean.BaseVgrOrganization;
import se.vgregion.ifeed.formbean.VgrOrganization;
import se.vgregion.ldap.LdapSupportService;

@Component
public class Json {

    private static LdapSupportService ldapSupportService;

    public static String toJson(Object obj) throws JsonGenerationException, JsonMappingException, IOException {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        new ObjectMapper().writeValue(baos, obj);
        baos.flush();
        baos.close();

        String r = new String(baos.toByteArray(), "UTF-8");
        return r;
    }

    public static String vgrHsaIdToJson(String id, Integer maxHits) throws JsonGenerationException,
            JsonMappingException, IOException {

        List<VgrOrganization> findings = ldapSupportService.find(new BaseVgrOrganization("Ou=Org", id),
                VgrOrganization.class);

        if (maxHits != null && findings.size() > maxHits.intValue()) {
            VgrOrganization vo = new VgrOrganization();
            vo.setOu("Hsa-id strängen matchade " + findings.size() + " träffar.");
            findings = new ArrayList<VgrOrganization>();
            findings.add(vo);
        }

        return toJson(findings);
    }

    public LdapSupportService getLdapSupportService() {
        return ldapSupportService;
    }

    @Autowired(required = true)
    public void setLdapSupportService(LdapSupportService ldapSupportService) {
        Json.ldapSupportService = ldapSupportService;
    }
}
